Lua_PeakAuctionWindow = class("Lua_PeakAuctionWindow", Lua_Window);
function Lua_PeakAuctionWindow:ctor()
	self:superCall("ctor");
	self.windowName = "Lua_PeakAuctionWindow";
	self.skinName = "PeakAuctionWindow_skin";
end

function Lua_PeakAuctionWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.my_bid = 0;
	self.numArr = Array();

	Lua_ProxyManager.getProxy("Lua_OperationalActivitiesProxy"):sGetActivityInfo(Lua_OperationalActivitiesData.ACT_PEAK_AUCTION);
    DataCenter.redDotData:updateRedDotVoState(22064, false);

    self.dragList = Lua_DragList.new(self.content,1, Vector4(0, 0, 580, 340));
    self.dragList:setLocation(-187, -48, 0);
    self.dragList:setListCell(Lua_PeakAuctionItem, 100, 579, 1);

    self.item = Lua_ToolImage.new(self.content);
    self.item:setDepth(10);
    self.item:setLocation(175, 110, 0);
    self.item:setCanClick(true);

    self.inputBg:addClickFuntion(self, self.onInputBgClick);
    self.inputBg.clickScale = false;
    self.clearBtn:addClickFuntion(self, self.onClearBtnClick);
    self.bidBtn:addClickFuntion(self, self.onBidBtnClick);
    self.addBtn_1:addClickFuntion(self, self.onAddBtnClick);
    self.addBtn_2:addClickFuntion(self, self.onAddBtnClick);
    self.addBtn_3:addClickFuntion(self, self.onAddBtnClick);
    self.winnerBtn:addClickFuntion(self, self.onWinnerBtnClick);
    self.help:addClickFuntion(self, self.onHelpBtnClick);

    self:addLuaEvent("UPDATE_PEAK_AUCTION", self, self.updatePanelInfo);
    self:addLuaEvent("PeakAuctionItem", self, self.onPeakAuctionItem);
    self:addLuaEvent("PeakAuctionItemSelected", self, self.onItemSelected);
end

function Lua_PeakAuctionWindow:dispose()
	self.my_bid = 0;
	if self.dragList ~= nil then
        self.dragList:dispose()
        self.dragList = nil;
    end
    Lua_CommonUtil.removeTimer(self, self.updateResidueTime);
    Lua_CommonUtil.removeTimer(self, self.updateItemEndTime);
    DataCenter.peakAuctionData.selectId = nil;
	self:superCall("dispose");
end

function Lua_PeakAuctionWindow:updatePanelInfo()
	local arr = DataCenter.peakAuctionData.getPeakAuctionData;
	self.dragList:setLuaArrayData(arr, false);

	local selectId = DataCenter.peakAuctionData.selectId;
	if selectId == nil then
		self.dragList.showList[1]:onPlayerSoundClick();
	end

    Lua_CommonUtil.addTimer("PeakAuction_ResidueTime", 1, self, self.updateResidueTime, nil, -1);
    self:updateResidueTime();
    self.periods.text = DataCenter.peakAuctionData.bidding_periods;
    self.tips.text = DataCenter.peakAuctionData.conditional_information;
end

function Lua_PeakAuctionWindow:onPeakAuctionItem(val)
	self.data = val;

	self.item.data = val.vo;

	self.money_1:setAltas("icon_atlas_3", "money_"..val.money_type);
	self.money_2:setAltas("icon_atlas_3", "money_"..val.money_type);
	self.money_3:setAltas("icon_atlas_3", "money_"..val.money_type);
	self.money_4:setAltas("icon_atlas_3", "money_"..val.money_type);

	self.itemName.text = val.vo.colorName;
	self.basePrice.text = LanUtil.formateStr(LanUtil.getValue(143200), tostring(val.clap_reserve));
	self.currentPrice.text = LanUtil.formateStr(LanUtil.getValue(143202), tostring(val.current_price));
	self.myBid.text = LanUtil.formateStr(LanUtil.getValue(143203), tostring(val.my_bid));
	self.bidPrice.text = "["..Lua_ColorDefine.RED_STR.."]"..val.current_price;
	self.my_bid = val.current_price;

	if val.raise_rule == 0 then
		self.addBtn_1.label = LanUtil.formateStr(LanUtil.getValue(143213), tostring(val.raise_limit[1]));
		self.addBtn_2.label = LanUtil.formateStr(LanUtil.getValue(143213), tostring(val.raise_limit[2]));
		self.addBtn_3.label = LanUtil.formateStr(LanUtil.getValue(143213), tostring(val.raise_limit[3]));
	elseif val.raise_rule == 1 then
		self.addBtn_1.label = LanUtil.formateStr(LanUtil.getValue(143212), tostring(val.raise_limit[1]));
		self.addBtn_2.label = LanUtil.formateStr(LanUtil.getValue(143212), tostring(val.raise_limit[2]));
		self.addBtn_3.label = LanUtil.formateStr(LanUtil.getValue(143212), tostring(val.raise_limit[3]));
	end

	Lua_CommonUtil.addTimer("AuctionItem_EndTime", 1, self, self.updateItemEndTime, nil, -1);
    self:updateItemEndTime();
end

function Lua_PeakAuctionWindow:onItemSelected(val)
	local arr = self.dragList.showList;
	local len = arr:getSize();

	for i = 1, len do
		if arr[i].data.index_id == val then
			arr[i]:setSelectedChange(true);
		else
			arr[i]:setSelectedChange(false);
		end
	end

	DataCenter.peakAuctionData.selectId = val;
end

-- 活动剩余时间
function Lua_PeakAuctionWindow:updateResidueTime()
    local left_time = tonumber(DataCenter.peakAuctionData.end_tick) - DataCenter.roleData.serverTime;
    if left_time > 0 then
        self.act_leftTime.text = LanUtil.formateStr(LanUtil.getValue(143204), TimeTransform.getInstance():transSeconds1(left_time, true));
    else
        self.act_leftTime.text = LanUtil.getValue(143209);
        Lua_CommonUtil.removeTimer(self, self.updateResidueTime);
    end
end

-- 刷新时间
function Lua_PeakAuctionWindow:updateItemEndTime()
    local end_time = tonumber(self.data.end_time) - DataCenter.roleData.serverTime;
    if end_time > 0 then
        self.end_time.text = LanUtil.formateStr(LanUtil.getValue(143201), TimeTransform.getInstance():transSeconds1(end_time, true));
    else
        self.end_time.text = LanUtil.getValue(143210);
        Lua_CommonUtil.removeTimer(self, self.updateItemEndTime);
    end
end

function Lua_PeakAuctionWindow:onInputBgClick()
	local list = {};
    list.pox = 290;
    list.poy = -5;
    list.callBackOwner = self;
    list.callBack = self.onInputCallBack;
    Lua_WindowUtil.openWin("Lua_CountInputWindow", WinParam.ACTION_AUTO, list);
end

function Lua_PeakAuctionWindow:onInputCallBack(data)
    if data.state == 3 then
    	self.my_bid = data.num;
    elseif data.state == 2 then
    	self.numArr:clear();
    elseif data.state == 1 then
    	self.bidPrice.text = "";
		self.numArr:add(data.num);
		for i = 1, self.numArr:getSize() do
			self.bidPrice.text = self.bidPrice.text..self.numArr[i];
		end
		self.my_bid = tonumber(self.bidPrice.text);
	elseif data.state == 0 then
		self.numArr:clear();
		self.my_bid = 0;
    end

    self:checkRange(self.my_bid);

    if self.my_bid > self.data.current_price then
	    self.bidPrice.text = "[973910]"..self.my_bid;
	else
		self.bidPrice.text = "["..Lua_ColorDefine.RED_STR.."]"..self.my_bid;
	end
end

function Lua_PeakAuctionWindow:checkRange(num)
    if self.my_bid >= 999999 then
        self.my_bid = 999999;
    elseif self.my_bid < 0 then
        self.my_bid = 0;
    else
        self.my_bid = num;
    end
end

function Lua_PeakAuctionWindow:onAddBtnClick(go)
	local str = string.split(tostring(go.gameObject.name), "_");
	local index = tonumber(str[2]);

	local num;
	if self.data.raise_rule == 0 then
		num = self.my_bid + self.data.raise_limit[index];
		self.my_bid = num;
	else
		num = self.my_bid + (self.my_bid * (self.data.raise_limit[index] / 100));
		self.my_bid = math.ceil(num);
	end

	if self.my_bid > self.data.current_price then
	    self.bidPrice.text = "[973910]"..self.my_bid;
	else
		self.bidPrice.text = "["..Lua_ColorDefine.RED_STR.."]"..self.my_bid;
	end
end

function Lua_PeakAuctionWindow:onClearBtnClick()
	self.my_bid = 0;
	self.bidPrice.text = "["..Lua_ColorDefine.RED_STR.."]"..self.my_bid;
end

function Lua_PeakAuctionWindow:onBidBtnClick()
	local end_time = tonumber(self.data.end_time) - DataCenter.roleData.serverTime;
	if end_time <= 0 then
		OperateAlert.show(LanUtil.getValue(143219));
		return;
	end

	if self.data.current_price == self.data.clap_reserve then -- 未被玩家出价
		if self.my_bid < self.data.current_price then
			OperateAlert.show(LanUtil.getValue(143217));
			return;
		else
			self:checkMoney();
		end
	else
		if self.data.raise_rule == 0 then
			local num = self.data.current_price + self.data.raise_limit[1];
			if self.my_bid < num then
				local str = LanUtil.formateStr(LanUtil.getValue(143215), tostring(self.data.raise_limit[1]));
				OperateAlert.show(str);
				return;
			else
				self:checkMoney();
			end
		elseif self.data.raise_rule == 1 then
			local num = self.data.current_price + (self.data.current_price * (self.data.raise_limit[1] / 100));
			if self.my_bid < num then
				local str = LanUtil.formateStr(LanUtil.getValue(143214), tostring(self.data.raise_limit[1]));
				OperateAlert.show(str);
				return;
			else
				self:checkMoney();
			end
		end
	end
end

function Lua_PeakAuctionWindow:checkMoney()
	if self.data.money_type == Lua_MoneyData.COPPER then
		if DataCenter.moneyData:getMoney(Lua_MoneyData.COPPER) < self.my_bid then
			DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.COPPER, self.my_bid, true, false);
		else
			Lua_ProxyManager.getProxy("Lua_PeakAuctionProxy"):sAuctionBidPrice(self.data.index_id, DataCenter.peakAuctionData.role_id, self.my_bid);
		end
	elseif self.data.money_type == Lua_MoneyData.BIND_GOLD then
		if DataCenter.moneyData:getMoney(Lua_MoneyData.BIND_GOLD) < self.my_bid then

			local tipData = {};
			tipData.des = LanUtil.getValue(127405);
			tipData.owner = self;
			tipData.type = 1;
			tipData.subFun = self.onSureFun;   --确定
			Lua_WindowUtil.openWin("Lua_TipsWindow", nil, tipData);
		else
			Lua_ProxyManager.getProxy("Lua_PeakAuctionProxy"):sAuctionBidPrice(self.data.index_id, DataCenter.peakAuctionData.role_id, self.my_bid);
		end
	elseif self.data.money_type == Lua_MoneyData.GOLD then
		if DataCenter.moneyData:getMoney(Lua_MoneyData.GOLD) < self.my_bid then
			DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD, self.my_bid, true, true);
		else
			Lua_ProxyManager.getProxy("Lua_PeakAuctionProxy"):sAuctionBidPrice(self.data.index_id, DataCenter.peakAuctionData.role_id, self.my_bid);
		end
	end
end

function Lua_PeakAuctionWindow:onSureFun()
	if DataCenter.moneyData:isMoneyEnough(Lua_MoneyData.GOLD_AND_BINDGOLD, self.my_bid, true, true) then
		Lua_ProxyManager.getProxy("Lua_PeakAuctionProxy"):sAuctionBidPrice(self.data.index_id, DataCenter.peakAuctionData.role_id, self.my_bid);
	end
end

function Lua_PeakAuctionWindow:onWinnerBtnClick()
	Lua_WindowUtil.openWin("Lua_AuctionWinnerWindow", WinParam.ACTION_OPEN);
end

function Lua_PeakAuctionWindow:onHelpBtnClick()
    Lua_WindowUtil.openWin("Lua_RuleTipWindow", WinParam.ACTION_OPEN, DataCenter.peakAuctionData.content);
end





















-----------------------------------------------------------------
Lua_PeakAuctionItem = class("Lua_PeakAuctionItem", Lua_ListCell);
function Lua_PeakAuctionItem:ctor(p)
    self:superCall("ctor", p, "PeakAuctionItem_skin");
end

function Lua_PeakAuctionItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemImg = Lua_ToolImage.new(self.content);
    self.itemImg:setDepth(10);
    self.itemImg:setLocation(-200, 12, 0);
    self.itemImg:setScale(0.7, 0.7, 1);
    self.itemImg:setCanClick(true);
end

function Lua_PeakAuctionItem:dispose()
	Lua_CommonUtil.removeTimer(self, self.updateEndTime);
	self:superCall("dispose");
end

function Lua_PeakAuctionItem:setData(data)
	self.data = data;

	self.itemImg.data = data.vo;
	self.itemName.text = data.vo.colorName;
	if data.item_effect == 1 then
		self.itemImg:showRoundEff(true);
		if roundEff ~= nil then
			self.itemImg.roundEff:setSacle(0.9,0.9,0.9);
			self.itemImg.roundEff:SetRenderQueue(self.itemImg.item_bg, 5, 2, true);
		end
	end

	self.money_1:setAltas("icon_atlas_3", "money_"..data.money_type);
	self.money_2:setAltas("icon_atlas_3", "money_"..data.money_type);

    if data.my_bid > 0 then
    	if data.current_price > data.my_bid then -- 出价被超过
	    	self.tips:setEnable(true);
	    	self.myPrice:setEnable(false);
	    	self.money_2:setEnable(false);
	    	self.tips.text = LanUtil.getValue(143206);
	    else
	    	self.tips:setEnable(false);
	    	self.myPrice:setEnable(true);
	    	self.money_2:setEnable(true);
	    	self.myPrice.text = tostring(data.my_bid);
	    end
	else
		self.tips:setEnable(true);
    	self.myPrice:setEnable(false);
    	self.money_2:setEnable(false);
    	self.tips.text = LanUtil.getValue(143205);
    end

    self.currentPrice.text = tostring(data.current_price);

	Lua_CommonUtil.addTimer("PeakAuctionItem_EndTime", 1, self, self.updateEndTime, nil, -1);
	self:updateEndTime();

	if data.index_id == DataCenter.peakAuctionData.selectId then
        self:setSelectedChange(true)
    else
        self:setSelectedChange(false)
    end
end

function Lua_PeakAuctionItem:checkOutBound(showRect)
	if self.itemImg.roundEff ~= nil then
		local rect = Lua_Rectangle.new(self.itemX, self.itemY - 25, 25, 50);
		if showRect:containeRect(rect) == true then
			self.itemImg.roundEff:setEnable(true);
		else
			self.itemImg.roundEff:setEnable(false);
		end
	end
end

function Lua_PeakAuctionItem:onPlayerSoundClick()
	Lua_MsgUtil.callFunc("PeakAuctionItemSelected", self.data.index_id);
end

function Lua_PeakAuctionItem:setSelectedChange(val)
    if self.bg ~= nil then
        if val == true then
            self.bg:setAltas("PeakAuction", "select_yes");
            Lua_MsgUtil.callFunc("PeakAuctionItem", self.data);
        else
            self.bg:setAltas("PeakAuction", "select_no");
        end
    end
end

-- 刷新时间
function Lua_PeakAuctionItem:updateEndTime()
    local end_time = tonumber(self.data.end_time) - DataCenter.roleData.serverTime;
    if end_time > 0 then
        self.end_time.text = TimeTransform.getInstance():transSeconds1(end_time, true);
    else
        self.end_time.text = LanUtil.getValue(143210);
        Lua_CommonUtil.removeTimer(self, self.updateEndTime);
    end
end